Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var LevelMap = map[ErrLevel]string{ ErrIgnorable: "ignorable", ErrInfo: "info", ErrNotice: "notice", ErrWarning: "warning", ErrError: "error", ErrCritical: "critical", ErrFatal: "fatal", ErrPanic: "panic", }
var StackEnabled = true
Functions ¶
Types ¶
type ErrLevel ¶
type ErrLevel int
Error severance level type. Can be used to determine the importance of the error before it handled appropriately.
type Frame ¶
type Frame uintptr
Frame represents a program counter inside a stack frame.
func (Frame) Format ¶
Format formats the frame according to the fmt.Formatter interface.
%s source file %d source line %n function name %v equivalent to %s:%d
Format accepts flags that alter the printing of some verbs, as follows:
%+s function name and path of source file relative to the compile time
GOPATH separated by \n\t (<funcname>\n\t<path>)
%+v equivalent to %+s:%d
type StackTrace ¶
type StackTrace []Frame
StackTrace is stack of Frames from innermost (newest) to outermost (oldest).
func (StackTrace) Format ¶
func (st StackTrace) Format(s fmt.State, verb rune)
Format formats the stack of Frames according to the fmt.Formatter interface.
%s lists source files for each Frame in the stack %v lists the source file and line number for each Frame in the stack
Format accepts flags that alter the printing of some verbs, as follows:
%+v Prints filename, function, and line number for each Frame in the stack.
Click to show internal directories.
Click to hide internal directories.